@@ -3,12 +3,28 @@ package IO::Easy;
 use Class::Easy;
 
 use vars qw($VERSION);
-$VERSION = '0.08';
+$VERSION = '0.09';
 
 use File::Spec;
 
 my $stat_methods = [qw(dev inode mode nlink uid gid rdev size atime mtime ctime blksize blocks)];
 
+sub import {
+	my $pack = shift;
+	my @params = @_;
+	
+	if (scalar grep {$_ eq 'script'} @params) {
+		
+		my $callpkg = caller;
+		
+		require IO::Easy::File;
+		require IO::Easy::Dir;
+		
+		sub ::file {'IO::Easy::File'}
+		sub ::dir  {'IO::Easy::Dir'}
+	}
+}
+
 foreach my $i (0 .. $#$stat_methods) {
 	has ($stat_methods->[$i], default => sub {
 		my $self = shift;
@@ -76,7 +92,6 @@ sub extension {
 	return $extension;
 }
 
-
 sub as_file {
 	my $self = shift;
 	
@@ -142,9 +157,9 @@ sub touch {
 sub abs_path {
 	my $self = shift;
 	
-	my $path = $self->{path};
+	my $pack = ref $self;
 	
-	return $FS->rel2abs ($path);
+	return $pack->new ($FS->rel2abs ($self->{path}));
 	
 }
 
@@ -225,15 +240,14 @@ with the simplicity similar to shell. The following operations can be
 used as an example: operations for recursive creation (mkdir -p) and
 removing (rm -rf), touching file.
 
-IO::Easy transparently processes file system paths independently
-from operating system with help of File::Spec module and does not
-require a lot of additional modules from CPAN.
+IO::Easy transparently handles OS path delimiters (e.g., Win* or *nix) using
+File::Spec module and does not require a lot of additional modules from CPAN.
 
 For better understanding of IO::Easy processing principles you should
 keep in mind that it operates with "Path Context". "Path Context" means
 that for any path in any file system IO::Easy takes path parts which are
 between path separators, but doesn't include path separators themselves,
-and tries to fetch the path in the current system from these path parts.
+and tries to build the path in the current system using these path parts.
 This way it can substitute different path separators from system to system
 (as long as they may differ depending on operating system, this also
 includes drive specification e.g. for Windows) and doesn't depend on
@@ -249,9 +263,24 @@ some system specifics of paths representation.
 	my $file = $io->append ('example.txt')->as_file;
 
 	my $content = "Some text goes here!";
-
+	
+	# Overwrite file contents with $content
 	$file->store ($content); 
+	
+or
+	
+	# easier scripts: you can replace IO::Easy::Dir for dir and so on
+	use IO::Easy qw(script);
+	
+	my $abs_path = dir->current->abs_path; # IO::Easy::Dir->current->abs_path;
 
+	my $test_file = file->new ('test');
+
+	$test_file->touch;
+
+	print "ok"
+		if -f $test_file and $test_file->size eq 0;
+	
 =head1 METHODS
 
 =head2 new
@@ -266,94 +295,123 @@ You can use method attach_interface for automatic object conversion
 for existing filesystem object or force type by using methods
 as_file or as_dir.
 
-=cut
+	Init file object:
 
-=head2 path
+	my $io = IO::Easy->new ('/');
 
-return current filesystem object path, also available as overload of ""
+	my $file = $io->append(qw(home user my_stuff.bak file.txt));
+
+In examples we will use this object to show results of method call.
 
 =cut
 
-=head2 name
+=head2 filesystem object path manipulation
 
-return current filesystem object name, without path
+=head3 path
+
+return current filesystem object path, also available as overload of "" # ???
+
+	# example :
+	$file->path	# /home/user/my_stuff/file.txt
 
 =cut
 
-=head2 base_name, extension
+=head3 name
+
+return current filesystem object name, without path (filename in most of cases)
+
+	# example :
+	$file->name	# file.txt
+
+=cut
+
+=head3 base_name, extension
 
 name part before last dot and after last dot
 
-=cut
-
-
-=head2 as_file, as_dir, attach_interface
-
-re bless object with specified or autodetected interface
-
-note: filesystem check for attach_interface
+	# example :
+	$file->base_name	# file
+	$file->extension	# txt
 
 =cut
 
-=head2 abs_path
+=head2 as_file, as_dir
+
+rebless object with specified type (currently 'dir' or 'file')
+
+=cut
+
+=head3 abs_path
 
 absolute path
 
+	# example :
+	$file->abs_path	# /home/user/my_stuff.bak/file.txt
+
 =cut
 
-=head2 append, append_in_place
+=head3 append, append_in_place
 
 append filesystem objects to IO::Easy object
 
 	my $config = IO::Easy::Dir->current->append (qw(etc config.json));
 
-produce …/etc/config.json on unix
+produce ./etc/config.json on unix
 
 =cut
 
-=head2 stat, modified, dev, inode, mode, nlink, uid, gid, rdev, size, atime, mtime, ctime, blksize, blocks
-
-complete stat array or this array accessors
-
-note: filesystem check
-
-=cut
-
-=head2 up, parent
+=head3 up, parent
 
 directory container for io object
 
-	my $config = IO::Easy::Dir->current->append (qw(etc config.json)); # '…/etc/config.json'
-	my $config_dir = $config->up; # '…/etc'
+	my $config = IO::Easy::Dir->current->append (qw(etc config.json)); # './etc/config.json'
+	my $config_dir = $config->up; # './etc'
 
 =cut
 
-=head2 rel_path
+=head3 rel_path
 
 relative path to specified directory
 	
-	my $current = IO::Easy::Dir->current; # '…'
-	my $config = $current->append (qw(etc config.json)); # '…/etc/config.json'
+	my $current = IO::Easy::Dir->current; # '.'
+	my $config = $current->append (qw(etc config.json)); # './etc/config.json'
 	my $config_rel = $config->rel_path ($current); # 'etc/config.json'
 
 =cut
 
-=head2 touch
-
-constructor for IO::Easy::Dir object
-	
-	my $current = IO::Easy::Dir->current; # '…'
-	my $config = $current->append (qw(etc config.json)); # '…/etc/config.json'
-	$config->touch; # file created
-
-=cut
-
-=head2 path_components
+=head3 path_components
 
 path, split by filesystem separators
 
 =cut
 
+=cut
+
+=head2 filesystem object manipulation
+
+=head3 attach_interface
+
+rebless object with autodetected filesystem object type
+
+=cut
+
+=head3 stat, modified, dev, inode, mode, nlink, uid, gid, rdev, size, atime, mtime, ctime, blksize, blocks
+
+complete stat array or this array accessors
+
+=cut
+
+=head3 touch
+
+constructor for IO::Easy::Dir object
+	
+	my $current = IO::Easy::Dir->current; # '.'
+	my $config = $current->append (qw(etc config.json)); # './etc/config.json'
+	$config->touch; # file created
+
+=cut
+
+=cut
 
 =head1 AUTHOR
 
